@@ -18,6 +18,7 @@ package commands
 import (
 	"context"
 	"fmt"
+	go_container_logs "github.com/google/go-containerregistry/pkg/logs"
 	"github.com/google/gops/agent"
 	"github.com/kluctl/kluctl/v2/pkg/prompts"
 	flag "github.com/spf13/pflag"
@@ -72,7 +73,9 @@ type cli struct {
 	Seal        sealCmd        `cmd:"" help:"Seal secrets based on target's sealingConfig"`
 	Validate    validateCmd    `cmd:"" help:"Validates the already deployed deployment"`
 	Controller  controllerCmd  `cmd:"" help:"Kluctl controller sub-commands"`
+	Gitops      gitopsCmd      `cmd:"" help:"GitOps sub-commands"`
 	Webui       webuiCmd       `cmd:"" help:"Kluctl Webui sub-commands"`
+	Oci         ociCmd         `cmd:"" help:"Oci sub-commands"`
 
 	Version versionCmd `cmd:"" help:"Print kluctl version"`
 }
@@ -82,8 +85,13 @@ var flagGroups = []groupInfo{
 	{group: "project", title: "Project arguments:", description: "Define where and how to load the kluctl project and its components from."},
 	{group: "images", title: "Image arguments:", description: "Control fixed images and update behaviour."},
 	{group: "inclusion", title: "Inclusion/Exclusion arguments:", description: "Control inclusion/exclusion."},
+	{group: "gitops", title: "GitOps arguments:", description: "Specify gitops flags."},
 	{group: "misc", title: "Misc arguments:", description: "Command specific arguments."},
 	{group: "results", title: "Command Results:", description: "Configure how command results are stored."},
+	{group: "logs", title: "Log arguments:", description: "Configure logging."},
+	{group: "override", title: "GitOps overrides:", description: "Override settings for GitOps deployments."},
+	{group: "helm", title: "Helm arguments:", description: "Configure Helm authentication."},
+	{group: "registry", title: "Registry arguments:", description: "Configure OCI registry authentication."},
 	{group: "auth", title: "Auth arguments:", description: "Configure authentication."},
 }
 
@@ -123,6 +131,10 @@ func redirectLogsAndStderr(ctx context.Context) {
 	log.SetOutput(lr2)
 	ctrl.SetLogger(klog.NewKlogr())
 
+	go_container_logs.Warn.SetOutput(status.NewLineRedirector(func(line string) {
+		status.Warning(ctx, line)
+	}))
+
 	pr, pw, err := os.Pipe()
 	if err != nil {
 		panic(err)
@@ -231,7 +243,7 @@ func (c *cli) Run(ctx context.Context) error {
 	return flag.ErrHelp
 }
 
-func initViper(ctx context.Context) {
+func initViper() {
 	viper.SetConfigName("config")
 	viper.SetConfigType("yaml")
 	viper.AddConfigPath("/etc/kluctl/")
@@ -248,8 +260,6 @@ func Main() {
 	colorable.EnableColorsStdout(nil)
 	ctx := context.Background()
 
-	initViper(ctx)
-
 	didSetupStatusHandler := false
 
 	err := Execute(ctx, os.Args[1:], func(ctxIn context.Context, cmd *cobra.Command, flags *GlobalFlags) (context.Context, error) {
@@ -257,16 +267,12 @@ func Main() {
 		if err != nil {
 			return ctx, err
 		}
-		err = copyViperValuesToCobraCmd(cmd)
-		if err != nil {
-			return ctx, err
-		}
 		err = setupProfiling(flags.CpuProfile)
 		if err != nil {
 			return ctx, err
 		}
 
-		ctx = initStatusHandlerAndPrompts(ctx, flags.Debug, flags.NoColor)
+		ctx = initStatusHandlerAndPrompts(ctxIn, flags.Debug, flags.NoColor)
 		didSetupStatusHandler = true
 
 		if cmd.Parent() == nil || (cmd.Name() != "run" && cmd.Parent().Name() != "controller") {
@@ -305,6 +311,16 @@ func Main() {
 	}
 }
 
+type cobraCmdContextKey struct{}
+
+func getCobraCommand(ctx context.Context) *cobra.Command {
+	v := ctx.Value(cobraCmdContextKey{})
+	if x, ok := v.(*cobra.Command); ok {
+		return x
+	}
+	return nil
+}
+
 func Execute(ctx context.Context, args []string, preRun func(ctx context.Context, rootCmd *cobra.Command, flags *GlobalFlags) (context.Context, error)) error {
 	root := cli{}
 	rootCmd, err := buildRootCobraCmd(&root, "kluctl",
@@ -324,6 +340,16 @@ composed of multiple smaller parts (Helm/Kustomize/...) in a manageable and unif
 	rootCmd.SilenceErrors = true
 
 	rootCmd.PersistentPreRunE = func(cmd *cobra.Command, args []string) error {
+		ctx = context.WithValue(ctx, cobraCmdContextKey{}, cmd)
+		for c := cmd; c != nil; c = c.Parent() {
+			c.SetContext(ctx)
+		}
+
+		err = copyViperValuesToCobraCmd(cmd)
+		if err != nil {
+			return err
+		}
+
 		if preRun != nil {
 			ctx, err = preRun(ctx, cmd, &root.GlobalFlags)
 			if ctx != nil {
@@ -338,14 +364,9 @@ composed of multiple smaller parts (Helm/Kustomize/...) in a manageable and unif
 		return nil
 	}
 
-	err = rootCmd.Execute()
-	if err != nil {
-		if status.FromContext(ctx) != nil {
-			status.Error(ctx, err.Error())
-		} else {
-			_, _ = fmt.Fprintf(os.Stderr, "%s\n", err.Error())
-		}
-		return err
-	}
-	return nil
+	return rootCmd.Execute()
+}
+
+func init() {
+	initViper()
 }
