@@ -32,10 +32,10 @@ func TestDiffName(t *testing.T) {
 			"kluctl.io/diff-name": "cm",
 		},
 	})
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-a", "cm_name=cm-1", "-a", "v=a")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-a", "cm_name=cm-1", "-a", "v=a")
 	assertConfigMapExists(t, k, p.TestSlug(), "cm-1")
 
-	resultStr, _ := p.KluctlMust("deploy", "--yes", "-t", "test", "-a", "cm_name=cm-2", "-a", "v=b", "-oyaml")
+	resultStr, _ := p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-a", "cm_name=cm-2", "-a", "v=b", "-oyaml")
 	assertConfigMapExists(t, k, p.TestSlug(), "cm-2")
 
 	var cr result.CompactedCommandResult
@@ -55,11 +55,11 @@ func TestDiffName(t *testing.T) {
 			{Type: "update", JsonPath: "metadata.name", OldValue: &v1.JSON{Raw: []byte("\"cm-1\"")}, NewValue: &v1.JSON{Raw: []byte("\"cm-2\"")}, UnifiedDiff: "-cm-1\n+cm-2"}},
 	}, r.Objects[0].BaseObject)
 	assert.Equal(t, result.BaseObject{
-		Ref:    k8s.ObjectRef{Version: "v1", Kind: "ConfigMap", Name: "cm-1", Namespace: "test-diff-name"},
+		Ref:    k8s.ObjectRef{Version: "v1", Kind: "ConfigMap", Name: "cm-1", Namespace: p.TestSlug()},
 		Orphan: true,
 	}, r.Objects[1].BaseObject)
 
-	resultStr, _ = p.KluctlMust("deploy", "--yes", "-t", "test", "-a", "cm_name=cm-3", "-a", "v=c", "-oyaml")
+	resultStr, _ = p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-a", "cm_name=cm-3", "-a", "v=c", "-oyaml")
 	assertConfigMapExists(t, k, p.TestSlug(), "cm-2")
 	err = yaml.ReadYamlString(resultStr, &cr)
 	assert.NoError(t, err)
@@ -77,11 +77,11 @@ func TestDiffName(t *testing.T) {
 			{Type: "update", JsonPath: "metadata.name", OldValue: &v1.JSON{Raw: []byte("\"cm-2\"")}, NewValue: &v1.JSON{Raw: []byte("\"cm-3\"")}, UnifiedDiff: "-cm-2\n+cm-3"}},
 	}, r.Objects[0].BaseObject)
 	assert.Equal(t, result.BaseObject{
-		Ref:    k8s.ObjectRef{Version: "v1", Kind: "ConfigMap", Name: "cm-1", Namespace: "test-diff-name"},
+		Ref:    k8s.ObjectRef{Version: "v1", Kind: "ConfigMap", Name: "cm-1", Namespace: p.TestSlug()},
 		Orphan: true,
 	}, r.Objects[1].BaseObject)
 	assert.Equal(t, result.BaseObject{
-		Ref:    k8s.ObjectRef{Version: "v1", Kind: "ConfigMap", Name: "cm-2", Namespace: "test-diff-name"},
+		Ref:    k8s.ObjectRef{Version: "v1", Kind: "ConfigMap", Name: "cm-2", Namespace: p.TestSlug()},
 		Orphan: true,
 	}, r.Objects[2].BaseObject)
 }
