@@ -1,58 +1,47 @@
 package e2e
 
 import (
-	"context"
 	kluctlv1 "github.com/kluctl/kluctl/v2/api/v1beta1"
 	test_utils "github.com/kluctl/kluctl/v2/e2e/test_project"
-	"github.com/kluctl/kluctl/v2/pkg/results"
 	"github.com/kluctl/kluctl/v2/pkg/types"
 	"github.com/kluctl/kluctl/v2/pkg/types/k8s"
 	"github.com/kluctl/kluctl/v2/pkg/types/result"
 	"github.com/kluctl/kluctl/v2/pkg/utils"
-	"github.com/kluctl/kluctl/v2/pkg/utils/flux_utils/meta"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
 	. "github.com/onsi/gomega"
+	"github.com/stretchr/testify/suite"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"sigs.k8s.io/controller-runtime/pkg/client"
+	"testing"
 )
 
-func (suite *GitopsTestSuite) getReadiness(obj *kluctlv1.KluctlDeployment) *metav1.Condition {
-	for _, c := range obj.Status.Conditions {
-		if c.Type == meta.ReadyCondition {
-			return &c
-		}
-	}
-	return nil
+type GitOpsErrorsSuite struct {
+	GitopsTestSuite
 }
 
-func (suite *GitopsTestSuite) assertErrors(key client.ObjectKey, rstatus metav1.ConditionStatus, rreason string, rmessage string, expectedErrors []result.DeploymentError, expectedWarnings []result.DeploymentError) {
-	g := NewWithT(suite.T())
+func TestGitOpsErrors(t *testing.T) {
+	t.Parallel()
+	suite.Run(t, new(GitOpsErrorsSuite))
+}
 
-	var kd kluctlv1.KluctlDeployment
-	err := suite.k.Client.Get(context.TODO(), key, &kd)
-	g.Expect(err).To(Succeed())
+func (suite *GitOpsErrorsSuite) assertErrors(kd *kluctlv1.KluctlDeployment, rstatus metav1.ConditionStatus, rreason string, rmessage string, expectedErrors []result.DeploymentError, expectedWarnings []result.DeploymentError) {
+	g := NewWithT(suite.T())
 
 	g.Expect(kd.Status.LastDeployResult).ToNot(BeNil())
 
-	readinessCondition := suite.getReadiness(&kd)
+	readinessCondition := suite.getReadiness(kd)
 	g.Expect(readinessCondition).ToNot(BeNil())
 
 	g.Expect(readinessCondition.Status).To(Equal(rstatus))
 	g.Expect(readinessCondition.Reason).To(Equal(rreason))
 	g.Expect(readinessCondition.Message).To(ContainSubstring(rmessage))
 
-	ctx, cancel := context.WithCancel(context.Background())
-	defer cancel()
-
-	rs, err := results.NewResultStoreSecrets(ctx, suite.k.RESTConfig(), suite.k.Client, "", 0, 0)
-	g.Expect(err).To(Succeed())
-
 	lastDeployResult, err := kd.Status.GetLastDeployResult()
 	g.Expect(err).To(Succeed())
-	cr, err := rs.GetCommandResult(results.GetCommandResultOptions{
-		Id: lastDeployResult.Id,
-	})
+
+	g.Expect(err).To(Succeed())
 	if len(expectedErrors) != 0 || len(expectedWarnings) != 0 {
+		cr := suite.getCommandResult(lastDeployResult.Id)
+		g.Expect(cr).ToNot(BeNil())
 		g.Expect(err).To(Succeed())
 		g.Expect(cr.Errors).To(ConsistOf(expectedErrors))
 		g.Expect(cr.Warnings).To(ConsistOf(expectedWarnings))
@@ -62,7 +51,7 @@ func (suite *GitopsTestSuite) assertErrors(key client.ObjectKey, rstatus metav1.
 	g.Expect(lastDeployResult.Warnings).To(ConsistOf(expectedWarnings))
 }
 
-func (suite *GitopsTestSuite) TestGitOpsErrors() {
+func (suite *GitOpsErrorsSuite) TestGitOpsErrors() {
 	g := NewWithT(suite.T())
 	_ = g
 
@@ -113,11 +102,11 @@ data:
 		p.UpdateFile("d1/cm1.yaml", func(f string) (string, error) {
 			return badCm1_1, nil
 		}, "")
-		suite.waitForReconcile(key)
-		suite.assertErrors(key, metav1.ConditionFalse, kluctlv1.DeployFailedReason, "deploy failed with 1 errors", []result.DeploymentError{
+		kd := suite.waitForReconcile(key)
+		suite.assertErrors(kd, metav1.ConditionFalse, kluctlv1.DeployFailedReason, "deploy failed with 1 errors", []result.DeploymentError{
 			{
 				Ref:     cm1Ref,
-				Message: "failed to patch test-git-ops-test-git-ops-errors/ConfigMap/cm1: failed to create typed patch object (test-git-ops-test-git-ops-errors/cm1; /v1, Kind=ConfigMap): .data_error: field not declared in schema",
+				Message: "failed to patch git-ops-errors-git-ops-errors/ConfigMap/cm1: failed to create typed patch object (git-ops-errors-git-ops-errors/cm1; /v1, Kind=ConfigMap): .data_error: field not declared in schema",
 			},
 		}, nil)
 		p.UpdateFile("d1/cm1.yaml", func(f string) (string, error) {
@@ -130,8 +119,8 @@ data:
 		p.UpdateFile("d1/cm1.yaml", func(f string) (string, error) {
 			return badCm1_2, nil
 		}, "")
-		suite.waitForReconcile(key)
-		suite.assertErrors(key, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "MalformedYAMLError: yaml: line 7: did not find expected node content in File: cm1.yaml", nil, nil)
+		kd := suite.waitForReconcile(key)
+		suite.assertErrors(kd, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "MalformedYAMLError: yaml: line 7: did not find expected node content in File: cm1.yaml", nil, nil)
 		p.UpdateFile("d1/cm1.yaml", func(f string) (string, error) {
 			return goodCm1, nil
 		}, "")
@@ -144,8 +133,8 @@ data:
 			kluctlBackup = f
 			return "a: b", nil
 		}, "")
-		suite.waitForReconcile(key)
-		suite.assertErrors(key, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, ".kluctl.yml failed: error unmarshaling JSON: while decoding JSON: json: unknown field \"a\"", nil, nil)
+		kd := suite.waitForReconcile(key)
+		suite.assertErrors(kd, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, ".kluctl.yml failed: error unmarshaling JSON: while decoding JSON: json: unknown field \"a\"", nil, nil)
 		p.UpdateFile(".kluctl.yml", func(f string) (string, error) {
 			return kluctlBackup, nil
 		}, "")
@@ -158,8 +147,8 @@ data:
 			deploymentBackup = f
 			return "a: b", nil
 		}, "")
-		suite.waitForReconcile(key)
-		suite.assertErrors(key, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "failed to load deployment.yml: error unmarshaling JSON: while decoding JSON: json: unknown field \"a\"", nil, nil)
+		kd := suite.waitForReconcile(key)
+		suite.assertErrors(kd, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "failed to load deployment.yml: error unmarshaling JSON: while decoding JSON: json: unknown field \"a\"", nil, nil)
 		p.UpdateFile("deployment.yml", func(f string) (string, error) {
 			return deploymentBackup, nil
 		}, "")
@@ -170,8 +159,8 @@ data:
 		suite.updateKluctlDeployment(key, func(kd *kluctlv1.KluctlDeployment) {
 			kd.Spec.Target = utils.StrPtr("invalid")
 		})
-		suite.waitForReconcile(key)
-		suite.assertErrors(key, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "target invalid not existent in kluctl project config", nil, nil)
+		kd := suite.waitForReconcile(key)
+		suite.assertErrors(kd, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "target invalid not existent in kluctl project config", nil, nil)
 		suite.updateKluctlDeployment(key, func(kd *kluctlv1.KluctlDeployment) {
 			kd.Spec.Target = utils.StrPtr("target1")
 		})
@@ -182,8 +171,8 @@ data:
 		suite.updateKluctlDeployment(key, func(kd *kluctlv1.KluctlDeployment) {
 			kd.Spec.Context = utils.StrPtr("invalid")
 		})
-		suite.waitForReconcile(key)
-		suite.assertErrors(key, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "context \"invalid\" does not exist", nil, nil)
+		kd := suite.waitForReconcile(key)
+		suite.assertErrors(kd, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "context \"invalid\" does not exist", nil, nil)
 		suite.updateKluctlDeployment(key, func(kd *kluctlv1.KluctlDeployment) {
 			kd.Spec.Context = utils.StrPtr("default")
 		})
@@ -191,30 +180,30 @@ data:
 	})
 
 	suite.Run("non existing git repo", func() {
-		var backup types.GitUrl
+		var backup string
 		suite.updateKluctlDeployment(key, func(kd *kluctlv1.KluctlDeployment) {
-			backup = kd.Spec.Source.URL
-			kd.Spec.Source.URL = *types.ParseGitUrlMust(backup.String() + "/invalid")
+			backup = kd.Spec.Source.Git.URL
+			kd.Spec.Source.Git.URL = backup + "/invalid"
 		})
-		suite.waitForReconcile(key)
-		suite.assertErrors(key, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "failed clone source: repository not found", nil, nil)
+		kd := suite.waitForReconcile(key)
+		suite.assertErrors(kd, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "failed to clone git source: repository not found", nil, nil)
 		suite.updateKluctlDeployment(key, func(kd *kluctlv1.KluctlDeployment) {
-			kd.Spec.Source.URL = backup
+			kd.Spec.Source.Git.URL = backup
 		})
 		suite.waitForCommit(key, getHeadRevision(suite.T(), p))
 	})
 	suite.Run("non existing git branch", func() {
 		var backup *types.GitRef
 		suite.updateKluctlDeployment(key, func(kd *kluctlv1.KluctlDeployment) {
-			backup = kd.Spec.Source.Ref
-			kd.Spec.Source.Ref = &types.GitRef{
+			backup = kd.Spec.Source.Git.Ref
+			kd.Spec.Source.Git.Ref = &types.GitRef{
 				Branch: "invalid",
 			}
 		})
-		suite.waitForReconcile(key)
-		suite.assertErrors(key, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "ref refs/heads/invalid not found", nil, nil)
+		kd := suite.waitForReconcile(key)
+		suite.assertErrors(kd, metav1.ConditionFalse, kluctlv1.PrepareFailedReason, "ref refs/heads/invalid not found", nil, nil)
 		suite.updateKluctlDeployment(key, func(kd *kluctlv1.KluctlDeployment) {
-			kd.Spec.Source.Ref = backup
+			kd.Spec.Source.Git.Ref = backup
 		})
 		suite.waitForCommit(key, getHeadRevision(suite.T(), p))
 	})
@@ -229,8 +218,8 @@ data:
 			_ = o.RemoveNestedField("discriminator")
 			return nil
 		})
-		suite.waitForCommit(key, getHeadRevision(suite.T(), p))
-		suite.assertErrors(key, metav1.ConditionFalse, kluctlv1.DeployFailedReason, "deploy failed with 1 errors", []result.DeploymentError{
+		kd := suite.waitForCommit(key, getHeadRevision(suite.T(), p))
+		suite.assertErrors(kd, metav1.ConditionFalse, kluctlv1.DeployFailedReason, "deploy failed with 1 errors", []result.DeploymentError{
 			{Message: "pruning without a discriminator is not supported"},
 		}, []result.DeploymentError{
 			{Message: "no discriminator configured. Orphan object detection will not work"},
@@ -239,8 +228,8 @@ data:
 			_ = o.SetNestedField(backup, "discriminator")
 			return nil
 		})
-		suite.waitForCommit(key, getHeadRevision(suite.T(), p))
-		suite.assertErrors(key, metav1.ConditionTrue, kluctlv1.ReconciliationSucceededReason, "deploy: ok", nil, nil)
+		kd = suite.waitForCommit(key, getHeadRevision(suite.T(), p))
+		suite.assertErrors(kd, metav1.ConditionTrue, kluctlv1.ReconciliationSucceededReason, "deploy succeeded", nil, nil)
 		suite.updateKluctlDeployment(key, func(kd *kluctlv1.KluctlDeployment) {
 			kd.Spec.Prune = false
 		})
