@@ -82,16 +82,15 @@ func assertValidate(t *testing.T, p *test_project.TestProject, succeed bool) (st
 	args := []string{"validate"}
 	args = append(args, "-t", "test")
 
-	stdout, stderr, err := p.Kluctl(args...)
+	stdout, stderr, err := p.Kluctl(t, args...)
 
 	if succeed {
 		assert.NoError(t, err)
 		assert.NotContains(t, stdout, fmt.Sprintf("%s/Deployment/d1: readyReplicas field not in status or empty", p.TestSlug()))
 		assert.NotContains(t, stderr, "Validation failed")
 	} else {
-		assert.Error(t, err)
+		assert.ErrorContains(t, err, "Validation failed")
 		assert.Contains(t, stdout, fmt.Sprintf("%s/Deployment/d1: readyReplicas field not in status or empty", p.TestSlug()))
-		assert.Contains(t, stderr, "Validation failed")
 	}
 
 	return stdout, stderr
@@ -104,7 +103,7 @@ func TestValidate(t *testing.T) {
 
 	p := prepareValidateTest(t, k)
 
-	p.KluctlMust("deploy", "--yes", "-t", "test")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test")
 	assertObjectExists(t, k, appsv1.SchemeGroupVersion.WithResource("deployments"), p.TestSlug(), "d1")
 
 	assertValidate(t, p, false)
