@@ -37,7 +37,7 @@ type DeploymentItem struct {
 	WaitReadiness bool
 
 	Objects []*uo.UnstructuredObject
-	Tags    *utils.OrderedMap
+	Tags    *utils.OrderedMap[string, bool]
 
 	RenderedSourceRootDir string
 	RelToSourceItemDir    string
@@ -191,7 +191,7 @@ func (di *DeploymentItem) newHelmRelease(subDir string) (*helm.Release, error) {
 		helmChartsDir = filepath.Join(di.Project.source.dir, ".helm-charts")
 	}
 
-	hr, err := helm.NewRelease(di.Project.source.dir, filepath.Join(di.RelToSourceItemDir, subDir), configPath, helmChartsDir, di.ctx.HelmCredentials)
+	hr, err := helm.NewRelease(di.ctx.Ctx, di.Project.source.dir, filepath.Join(di.RelToSourceItemDir, subDir), configPath, helmChartsDir, di.ctx.HelmAuthProvider, di.ctx.OciAuthProvider)
 	if err != nil {
 		return nil, err
 	}
@@ -499,8 +499,8 @@ func (di *DeploymentItem) prepareKustomizationYaml() (*uo.UnstructuredObject, er
 		}
 	}
 
-	di.Barrier = utils.ParseBoolOrFalse(ky.GetK8sAnnotation("kluctl.io/barrier"))
-	di.WaitReadiness = utils.ParseBoolOrFalse(ky.GetK8sAnnotation("kluctl.io/wait-readiness"))
+	di.Barrier = ky.GetK8sAnnotationBoolNoError("kluctl.io/barrier", false)
+	di.WaitReadiness = ky.GetK8sAnnotationBoolNoError("kluctl.io/wait-readiness", false)
 
 	return ky, nil
 }
