@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"github.com/go-git/go-git/v5/plumbing/transport"
 	ssh2 "github.com/go-git/go-git/v5/plumbing/transport/ssh"
+	"github.com/hashicorp/go-multierror"
 	"github.com/kluctl/kluctl/v2/pkg/git/messages"
 	"github.com/kluctl/kluctl/v2/pkg/types"
 	"golang.org/x/crypto/ssh"
@@ -26,7 +27,7 @@ func (a *AuthMethodAndCA) SshClientConfig() (*ssh.ClientConfig, error) {
 }
 
 type GitAuthProvider interface {
-	BuildAuth(ctx context.Context, gitUrl types.GitUrl) AuthMethodAndCA
+	BuildAuth(ctx context.Context, gitUrl types.GitUrl) (AuthMethodAndCA, error)
 }
 
 type GitAuthProviders struct {
@@ -41,14 +42,20 @@ func (a *GitAuthProviders) RegisterAuthProvider(p GitAuthProvider, last bool) {
 	}
 }
 
-func (a *GitAuthProviders) BuildAuth(ctx context.Context, gitUrl types.GitUrl) AuthMethodAndCA {
+func (a *GitAuthProviders) BuildAuth(ctx context.Context, gitUrl types.GitUrl) (AuthMethodAndCA, error) {
+	var errs *multierror.Error
 	for _, p := range a.authProviders {
-		auth := p.BuildAuth(ctx, gitUrl)
-		if auth.AuthMethod != nil {
-			return auth
+		auth, err := p.BuildAuth(ctx, gitUrl)
+		if err != nil {
+			errs = multierror.Append(errs, err)
+			continue
 		}
+		if auth.AuthMethod == nil {
+			continue
+		}
+		return auth, nil
 	}
-	return AuthMethodAndCA{}
+	return AuthMethodAndCA{}, errs.ErrorOrNil()
 }
 
 func NewDefaultAuthProviders(envPrefix string, messageCallbacks *messages.MessageCallbacks) *GitAuthProviders {
