@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"github.com/kluctl/go-jinja2"
 	"github.com/kluctl/kluctl/v2/pkg/repocache"
-	"github.com/kluctl/kluctl/v2/pkg/sops/decryptor"
 	types2 "github.com/kluctl/kluctl/v2/pkg/types"
 	"time"
 )
@@ -13,16 +12,14 @@ type LoadedKluctlProject struct {
 	LoadArgs LoadKluctlProjectArgs
 	LoadTime time.Time
 
-	TmpDir string
-
-	sealedSecretsDir string
+	SealedSecretsDir string
 
 	Config  types2.KluctlProject
 	Targets []*types2.Target
 
-	J2            *jinja2.Jinja2
-	RP            *repocache.GitRepoCache
-	SopsDecrypter *decryptor.Decryptor
+	J2    *jinja2.Jinja2
+	GitRP *repocache.GitRepoCache
+	OciRP *repocache.OciRepoCache
 }
 
 func (c *LoadedKluctlProject) FindTarget(name string) (*types2.Target, error) {
