@@ -36,6 +36,7 @@ type ResultStoreSecrets struct {
 	validateResultsCache cache.Cache
 	clusterId            string
 
+	allowWrite               bool
 	writeNamespace           string
 	keepCommandResultsCount  int
 	keepValidateResultsCount int
@@ -43,7 +44,7 @@ type ResultStoreSecrets struct {
 	mutex sync.Mutex
 }
 
-func NewResultStoreSecrets(ctx context.Context, config *rest.Config, client_ client.Client, writeNamespace string, keepCommandResultsCount int, keepValidateResultsCount int) (*ResultStoreSecrets, error) {
+func NewResultStoreSecrets(ctx context.Context, config *rest.Config, client_ client.Client, allowWrite bool, writeNamespace string, keepCommandResultsCount int, keepValidateResultsCount int) (*ResultStoreSecrets, error) {
 	clusterId, err := k8s.GetClusterId(ctx, client_)
 	if err != nil {
 		return nil, err
@@ -73,6 +74,7 @@ func NewResultStoreSecrets(ctx context.Context, config *rest.Config, client_ cli
 	s := &ResultStoreSecrets{
 		ctx:                      ctx,
 		client:                   client_,
+		allowWrite:               allowWrite,
 		writeNamespace:           writeNamespace,
 		cache:                    c1,
 		clusterId:                clusterId,
@@ -88,8 +90,8 @@ var invalidChars = regexp.MustCompile(`[^a-zA-Z0-9-]`)
 func (s *ResultStoreSecrets) buildName(prefix string, id string, projectKey result.ProjectKey) string {
 	name := ""
 
-	if projectKey.GitRepoKey.Path != "" {
-		name = path.Base(projectKey.GitRepoKey.Path)
+	if projectKey.RepoKey.Path != "" {
+		name = path.Base(projectKey.RepoKey.Path)
 	}
 
 	name = strings.ReplaceAll(name, "_", "-")
@@ -115,6 +117,9 @@ func (s *ResultStoreSecrets) ensureWriteNamespace() error {
 	if s.writeNamespace == "" {
 		return fmt.Errorf("missing writeNamespace")
 	}
+	if !s.allowWrite {
+		return fmt.Errorf("result store is read-only")
+	}
 	var ns corev1.Namespace
 	err := s.client.Get(s.ctx, client.ObjectKey{Name: s.writeNamespace}, &ns)
 	if err != nil && errors.IsNotFound(err) {
@@ -135,6 +140,10 @@ func (s *ResultStoreSecrets) ensureWriteNamespace() error {
 }
 
 func (s *ResultStoreSecrets) WriteCommandResult(cr *result.CommandResult) error {
+	if !s.allowWrite {
+		return fmt.Errorf("result store is read-only")
+	}
+
 	err := s.ensureWriteNamespace()
 	if err != nil {
 		return err
@@ -185,8 +194,8 @@ func (s *ResultStoreSecrets) WriteCommandResult(cr *result.CommandResult) error
 			"compactedObjects": compressedObjects,
 		},
 	}
-	if cr.ProjectKey.GitRepoKey.String() != "" {
-		secret.Annotations["kluctl.io/result-project-repo-key"] = cr.ProjectKey.GitRepoKey.String()
+	if cr.ProjectKey.RepoKey.String() != "" {
+		secret.Annotations["kluctl.io/result-project-repo-key"] = cr.ProjectKey.RepoKey.String()
 	}
 	if cr.ProjectKey.SubDir != "" {
 		secret.Annotations["kluctl.io/result-project-subdir"] = cr.ProjectKey.SubDir
@@ -209,7 +218,31 @@ func (s *ResultStoreSecrets) WriteCommandResult(cr *result.CommandResult) error
 	return nil
 }
 
+func (s *ResultStoreSecrets) DeleteCommandResult(rsId string) error {
+	if !s.allowWrite {
+		return fmt.Errorf("result store is read-only")
+	}
+	if rsId == "" {
+		return fmt.Errorf("empty rsId is not allowed")
+	}
+
+	var tmp corev1.Secret
+	err := s.client.DeleteAllOf(s.ctx, &tmp,
+		client.InNamespace(s.writeNamespace),
+		client.MatchingLabels{
+			"kluctl.io/command-result-id": rsId,
+		})
+	if err != nil {
+		return err
+	}
+	return nil
+}
+
 func (s *ResultStoreSecrets) WriteValidateResult(vr *result.ValidateResult) error {
+	if !s.allowWrite {
+		return fmt.Errorf("result store is read-only")
+	}
+
 	err := s.ensureWriteNamespace()
 	if err != nil {
 		return err
@@ -250,8 +283,8 @@ func (s *ResultStoreSecrets) WriteValidateResult(vr *result.ValidateResult) erro
 			"result": compressedVr,
 		},
 	}
-	if vr.ProjectKey.GitRepoKey.String() != "" {
-		secret.Annotations["kluctl.io/result-project-repo-key"] = vr.ProjectKey.GitRepoKey.String()
+	if vr.ProjectKey.RepoKey.String() != "" {
+		secret.Annotations["kluctl.io/result-project-repo-key"] = vr.ProjectKey.RepoKey.String()
 	}
 	if vr.ProjectKey.SubDir != "" {
 		secret.Annotations["kluctl.io/result-project-subdir"] = vr.ProjectKey.SubDir
@@ -275,6 +308,10 @@ func (s *ResultStoreSecrets) WriteValidateResult(vr *result.ValidateResult) erro
 }
 
 func (s *ResultStoreSecrets) cleanupOldCommandResults(project result.ProjectKey, target result.TargetKey) error {
+	if !s.allowWrite {
+		return fmt.Errorf("result store is read-only")
+	}
+
 	results, err := s.ListCommandResultSummaries(ListResultSummariesOptions{
 		ProjectFilter: &project,
 	})
@@ -304,6 +341,10 @@ func (s *ResultStoreSecrets) cleanupOldCommandResults(project result.ProjectKey,
 }
 
 func (s *ResultStoreSecrets) cleanupOrphanedResults() error {
+	if !s.allowWrite {
+		return fmt.Errorf("result store is read-only")
+	}
+
 	commandResults, err := s.doListCommandResultSummaries(ListResultSummariesOptions{})
 	if err != nil {
 		return err
@@ -324,6 +365,9 @@ func (s *ResultStoreSecrets) cleanupOrphanedResults() error {
 	}
 
 	tryDeleteResult := func(secretKey client.ObjectKey, deployment *result.KluctlDeploymentInfo, id string, t string) {
+		if secretKey.Namespace != s.writeNamespace {
+			return
+		}
 		if _, ok := deploymentsMap[*deployment]; ok {
 			return
 		}
@@ -357,6 +401,10 @@ func (s *ResultStoreSecrets) cleanupOrphanedResults() error {
 }
 
 func (s *ResultStoreSecrets) StartCleanupOrphans() error {
+	if !s.allowWrite {
+		return fmt.Errorf("result store is read-only")
+	}
+
 	ch, _, err := s.WatchKluctlDeployments()
 	if err != nil {
 		return err
@@ -793,10 +841,12 @@ func (s *ResultStoreSecrets) ListKluctlDeployments() ([]WatchKluctlDeploymentEve
 	}
 	ret := make([]WatchKluctlDeploymentEvent, 0, len(l.Items))
 	for _, x := range l.Items {
-		x := x
+		o := x.DeepCopy()
+		o.Kind = kluctlv1.KluctlDeploymentKind
+		o.APIVersion = kluctlv1.GroupVersion.String()
 		ret = append(ret, WatchKluctlDeploymentEvent{
 			ClusterId:  s.clusterId,
-			Deployment: &x,
+			Deployment: o,
 		})
 	}
 	return ret, nil
@@ -816,6 +866,7 @@ func (s *ResultStoreSecrets) WatchKluctlDeployments() (<-chan WatchKluctlDeploym
 		if o == nil {
 			return nil
 		}
+		o = o.DeepCopy()
 		o.Kind = kluctlv1.KluctlDeploymentKind
 		o.APIVersion = kluctlv1.GroupVersion.String()
 		return &WatchKluctlDeploymentEvent{
