@@ -38,6 +38,7 @@ type WatchKluctlDeploymentEvent struct {
 type ResultStore interface {
 	WriteCommandResult(cr *result.CommandResult) error
 	WriteValidateResult(vr *result.ValidateResult) error
+	DeleteCommandResult(rsId string) error
 
 	ListCommandResultSummaries(options ListResultSummariesOptions) ([]result.CommandResultSummary, error)
 	WatchCommandResultSummaries(options ListResultSummariesOptions) (<-chan WatchCommandResultSummaryEvent, context.CancelFunc, error)
@@ -54,7 +55,7 @@ type ResultStore interface {
 
 func FilterProject(x result.ProjectKey, filter *result.ProjectKey) bool {
 	if filter != nil {
-		if filter.GitRepoKey.String() != "" && x.GitRepoKey != filter.GitRepoKey {
+		if filter.RepoKey.String() != "" && x.RepoKey != filter.RepoKey {
 			return false
 		}
 		if filter.SubDir != "" && x.SubDir != filter.SubDir {
@@ -71,7 +72,10 @@ func lessCommandSummary(a *result.CommandResultSummary, b *result.CommandResultS
 	if a.Command.EndTime != b.Command.EndTime {
 		return a.Command.EndTime.After(b.Command.EndTime.Time)
 	}
-	return a.Command.Command < b.Command.Command
+	if a.Command.Command != b.Command.Command {
+		return a.Command.Command < b.Command.Command
+	}
+	return a.Id < b.Id
 }
 
 func lessValidateSummary(a *result.ValidateResultSummary, b *result.ValidateResultSummary) bool {
@@ -81,5 +85,5 @@ func lessValidateSummary(a *result.ValidateResultSummary, b *result.ValidateResu
 	if a.EndTime != b.EndTime {
 		return a.EndTime.After(b.EndTime.Time)
 	}
-	return false
+	return a.Id < b.Id
 }
