@@ -9,9 +9,9 @@ func TestParseEnvConfigSets_Prefixes(t *testing.T) {
 	t.Setenv("PREFIX_A", "a")
 	t.Setenv("PREFIX_B", "b")
 	t.Setenv("PREFIX2_C", "c")
-	assert.Equal(t, map[int]map[string]string{}, ParseEnvConfigSets("DUMMY"))
-	assert.Equal(t, map[int]map[string]string{-1: {"A": "a", "B": "b"}}, ParseEnvConfigSets("PREFIX"))
-	assert.Equal(t, map[int]map[string]string{-1: {"C": "c"}}, ParseEnvConfigSets("PREFIX2"))
+	assert.Equal(t, []EnvSet(nil), ParseEnvConfigSets("DUMMY"))
+	assert.Equal(t, []EnvSet{{Index: -1, Map: map[string]string{"A": "a", "B": "b"}}}, ParseEnvConfigSets("PREFIX"))
+	assert.Equal(t, []EnvSet{{Index: -1, Map: map[string]string{"C": "c"}}}, ParseEnvConfigSets("PREFIX2"))
 }
 
 func TestParseEnvConfigSets_Indexes(t *testing.T) {
@@ -19,7 +19,7 @@ func TestParseEnvConfigSets_Indexes(t *testing.T) {
 	t.Setenv("PREFIX_0_A", "a0")
 	t.Setenv("PREFIX_0_B", "b0")
 	t.Setenv("PREFIX_1_A", "a1")
-	assert.Equal(t, map[int]map[string]string{-1: {"A": "a"}, 0: {"A": "a0", "B": "b0"}, 1: {"A": "a1"}}, ParseEnvConfigSets("PREFIX"))
+	assert.Equal(t, []EnvSet{{Index: -1, Map: map[string]string{"A": "a"}}, {Index: 0, Map: map[string]string{"A": "a0", "B": "b0"}}, {Index: 1, Map: map[string]string{"A": "a1"}}}, ParseEnvConfigSets("PREFIX"))
 }
 
 func TestParseEnvConfigList(t *testing.T) {
