@@ -8,6 +8,9 @@ import (
 	types2 "github.com/aws/aws-sdk-go-v2/service/secretsmanager/types"
 	"github.com/getsops/sops/v3/cmd/sops/formats"
 	"github.com/kluctl/go-jinja2"
+	"github.com/kluctl/kluctl/v2/pkg/clouds/aws"
+	"github.com/kluctl/kluctl/v2/pkg/clouds/azure"
+	"github.com/kluctl/kluctl/v2/pkg/clouds/gcp"
 	"github.com/kluctl/kluctl/v2/pkg/k8s"
 	"github.com/kluctl/kluctl/v2/pkg/repocache"
 	"github.com/kluctl/kluctl/v2/pkg/sops"
@@ -17,7 +20,6 @@ import (
 	k8s2 "github.com/kluctl/kluctl/v2/pkg/types/k8s"
 	"github.com/kluctl/kluctl/v2/pkg/utils"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
-	"github.com/kluctl/kluctl/v2/pkg/vars/aws"
 	"github.com/kluctl/kluctl/v2/pkg/vars/vault"
 	"github.com/kluctl/kluctl/v2/pkg/yaml"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -37,17 +39,19 @@ type VarsLoader struct {
 	sops *decryptor.Decryptor
 	rp   *repocache.GitRepoCache
 	aws  aws.AwsClientFactory
+	gcp  gcp.GcpClientFactory
 
 	credentialsCache map[string]usernamePassword
 }
 
-func NewVarsLoader(ctx context.Context, k *k8s.K8sCluster, sops *decryptor.Decryptor, rp *repocache.GitRepoCache, aws aws.AwsClientFactory) *VarsLoader {
+func NewVarsLoader(ctx context.Context, k *k8s.K8sCluster, sops *decryptor.Decryptor, rp *repocache.GitRepoCache, aws aws.AwsClientFactory, gcp gcp.GcpClientFactory) *VarsLoader {
 	return &VarsLoader{
 		ctx:              ctx,
 		k:                k,
 		sops:             sops,
 		rp:               rp,
 		aws:              aws,
+		gcp:              gcp,
 		credentialsCache: map[string]usernamePassword{},
 	}
 }
@@ -122,9 +126,15 @@ func (v *VarsLoader) LoadVars(ctx context.Context, varsCtx *VarsCtx, sourceIn *t
 	} else if source.AwsSecretsManager != nil {
 		newVars, err = v.loadAwsSecretsManager(varsCtx, &source, ignoreMissing)
 		sensitive = true
+	} else if source.GcpSecretManager != nil {
+		newVars, err = v.loadGcpSecretManager(varsCtx, &source, ignoreMissing)
+		sensitive = true
 	} else if source.Vault != nil {
 		newVars, err = v.loadVault(varsCtx, &source, ignoreMissing)
 		sensitive = true
+	} else if source.AzureKeyVault != nil {
+		newVars, err = v.loadAzureKeyVault(varsCtx, &source, ignoreMissing)
+		sensitive = true
 	} else {
 		return fmt.Errorf("invalid vars source")
 	}
@@ -259,6 +269,38 @@ func (v *VarsLoader) loadAwsSecretsManager(varsCtx *VarsCtx, source *types.VarsS
 	return v.loadFromString(varsCtx, secret)
 }
 
+func (v *VarsLoader) loadGcpSecretManager(varsCtx *VarsCtx, source *types.VarsSource, ignoreMissing bool) (*uo.UnstructuredObject, error) {
+	if v.gcp == nil {
+		return uo.New(), fmt.Errorf("no GCP client factory provided")
+	}
+
+	secret, err := gcp.GetGoogleSecretsManagerSecret(v.ctx, v.gcp, source.GcpSecretManager.SecretName)
+	if err != nil {
+		if strings.Contains(err.Error(), "NotFound") {
+			if ignoreMissing {
+				return uo.New(), nil
+			}
+			return nil, fmt.Errorf("secret not found: %v", err)
+		}
+		return nil, err
+	}
+	return v.loadFromString(varsCtx, secret)
+}
+
+func (v *VarsLoader) loadAzureKeyVault(varsCtx *VarsCtx, source *types.VarsSource, ignoreMissing bool) (*uo.UnstructuredObject, error) {
+	secret, err := azure.GetAzureKeyVaultSecret(v.ctx, source.AzureKeyVault.VaultUri, source.AzureKeyVault.SecretName)
+	if err != nil {
+		return nil, err
+	}
+	if secret == "" {
+		if ignoreMissing {
+			return uo.New(), nil
+		}
+		return nil, fmt.Errorf("the specified azure-key-vault secret was not found")
+	}
+	return v.loadFromString(varsCtx, secret)
+}
+
 func (v *VarsLoader) loadVault(varsCtx *VarsCtx, source *types.VarsSource, ignoreMissing bool) (*uo.UnstructuredObject, error) {
 	secret, err := vault.GetSecret(source.Vault.Address, source.Vault.Path)
 	if err != nil {
@@ -274,7 +316,7 @@ func (v *VarsLoader) loadVault(varsCtx *VarsCtx, source *types.VarsSource, ignor
 }
 
 func (v *VarsLoader) loadGit(ctx context.Context, varsCtx *VarsCtx, gitFile *types.VarsSourceGit, ignoreMissing bool) (*uo.UnstructuredObject, bool, error) {
-	ge, err := v.rp.GetEntry(gitFile.Url)
+	ge, err := v.rp.GetEntry(gitFile.Url.String())
 	if err != nil {
 		return nil, false, err
 	}
