@@ -5,6 +5,8 @@ import (
 	"fmt"
 	"github.com/huandu/xstrings"
 	test_utils "github.com/kluctl/kluctl/v2/e2e/test-utils"
+	"github.com/kluctl/kluctl/v2/pkg/clouds/aws"
+	"github.com/kluctl/kluctl/v2/pkg/clouds/gcp"
 	"github.com/kluctl/kluctl/v2/pkg/sops/decryptor"
 	"github.com/stretchr/testify/suite"
 	"io"
@@ -19,7 +21,6 @@ import (
 	"github.com/getsops/sops/v3/age"
 	git2 "github.com/go-git/go-git/v5"
 	"github.com/go-git/go-git/v5/plumbing"
-	"github.com/kluctl/kluctl/v2/pkg/git"
 	"github.com/kluctl/kluctl/v2/pkg/git/auth"
 	ssh_pool "github.com/kluctl/kluctl/v2/pkg/git/ssh-pool"
 	"github.com/kluctl/kluctl/v2/pkg/k8s"
@@ -27,7 +28,6 @@ import (
 	"github.com/kluctl/kluctl/v2/pkg/types"
 	"github.com/kluctl/kluctl/v2/pkg/utils"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
-	"github.com/kluctl/kluctl/v2/pkg/vars/aws"
 	"github.com/kluctl/kluctl/v2/pkg/vars/sops_test_resources"
 	"github.com/stretchr/testify/assert"
 	corev1 "k8s.io/api/core/v1"
@@ -82,21 +82,22 @@ func (s *VarsLoaderTestSuite) newRP() *repocache.GitRepoCache {
 	return grc
 }
 
-func (s *VarsLoaderTestSuite) testVarsLoader(test func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory)) {
+func (s *VarsLoaderTestSuite) testVarsLoader(test func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory)) {
 	grc := s.newRP()
 	fakeAws := aws.NewFakeClientFactory()
+	fakeGcp := gcp.NewFakeClientFactory()
 
 	d := decryptor.NewDecryptor("", decryptor.MaxEncryptedFileSize)
 	d.AddLocalKeyService()
 
-	vl := NewVarsLoader(context.TODO(), s.k2, d, grc, fakeAws)
+	vl := NewVarsLoader(context.TODO(), s.k2, d, grc, fakeAws, fakeGcp)
 	vc := NewVarsCtx(newJinja2Must(s.T()))
 
-	test(vl, vc, fakeAws)
+	test(vl, vc, fakeAws, fakeGcp)
 }
 
 func (s *VarsLoaderTestSuite) TestValues() {
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Values: uo.FromStringMust(`{"test1": {"test2": 42}}`),
 		}, nil, "")
@@ -108,7 +109,7 @@ func (s *VarsLoaderTestSuite) TestValues() {
 }
 
 func (s *VarsLoaderTestSuite) TestValuesNoOverrides() {
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Values: uo.FromStringMust(`{"test1": {"test2": 42}}`),
 		}, nil, "")
@@ -127,7 +128,7 @@ func (s *VarsLoaderTestSuite) TestValuesNoOverrides() {
 }
 
 func (s *VarsLoaderTestSuite) TestWhen() {
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Values: uo.FromStringMust(`{"test1": "a"}`),
 		}, nil, "")
@@ -154,7 +155,7 @@ func (s *VarsLoaderTestSuite) TestFile() {
 	d := s.T().TempDir()
 	_ = os.WriteFile(filepath.Join(d, "test.yaml"), []byte(`{"test1": {"test2": 42}}`), 0o600)
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		vs := &types.VarsSource{
 			File: utils.StrPtr("test.yaml"),
 		}
@@ -166,7 +167,7 @@ func (s *VarsLoaderTestSuite) TestFile() {
 		assert.False(s.T(), vs.RenderedSensitive)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		b := true
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			IgnoreMissing: &b,
@@ -178,7 +179,7 @@ func (s *VarsLoaderTestSuite) TestFile() {
 		assert.Equal(s.T(), int64(42), v)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		b := true
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			IgnoreMissing: &b,
@@ -196,7 +197,7 @@ func (s *VarsLoaderTestSuite) TestSopsFile() {
 
 	s.T().Setenv(age.SopsAgeKeyEnv, string(key))
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		vs := &types.VarsSource{
 			File: utils.StrPtr("test.yaml"),
 		}
@@ -214,7 +215,7 @@ func (s *VarsLoaderTestSuite) TestFileWithLoad() {
 	_ = os.WriteFile(filepath.Join(d, "test.yaml"), []byte(`{"test1": {"test2": {{ load_template("test2.txt") }}}}`), 0o600)
 	_ = os.WriteFile(filepath.Join(d, "test2.txt"), []byte(`42`), 0o600)
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			File: utils.StrPtr("test.yaml"),
 		}, []string{d}, "")
@@ -231,7 +232,7 @@ func (s *VarsLoaderTestSuite) TestFileWithLoadSubDir() {
 	_ = os.WriteFile(filepath.Join(d, "test.yaml"), []byte(`{"test1": {"test2": {{ load_template("test2.txt") }}}}`), 0o600)
 	_ = os.WriteFile(filepath.Join(d, "subdir/test2.txt"), []byte(`42`), 0o600)
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			File: utils.StrPtr("test.yaml"),
 		}, []string{d, filepath.Join(d, "subdir")}, "")
@@ -246,7 +247,7 @@ func (s *VarsLoaderTestSuite) TestFileWithLoadNotExists() {
 	d := s.T().TempDir()
 	_ = os.WriteFile(filepath.Join(d, "test.yaml"), []byte(`{"test1": {"test2": {{load_template("test3.txt")}}}}`), 0o600)
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			File: utils.StrPtr("test.yaml"),
 		}, []string{d}, "")
@@ -255,7 +256,7 @@ func (s *VarsLoaderTestSuite) TestFileWithLoadNotExists() {
 }
 
 func (s *VarsLoaderTestSuite) TestGit() {
-	gs := git.NewTestGitServer(s.T())
+	gs := test_utils.NewTestGitServer(s.T())
 	gs.GitInit("repo")
 	gs.UpdateYaml("repo", "test.yaml", func(o map[string]any) error {
 		o["test1"] = map[string]any{
@@ -264,7 +265,7 @@ func (s *VarsLoaderTestSuite) TestGit() {
 		return nil
 	}, "")
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		url, _ := types.ParseGitUrl(gs.GitRepoUrl("repo"))
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Git: &types.VarsSourceGit{
@@ -278,7 +279,7 @@ func (s *VarsLoaderTestSuite) TestGit() {
 		assert.Equal(s.T(), int64(42), v)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		url, _ := types.ParseGitUrl(gs.GitRepoUrl("repo"))
 		b := true
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
@@ -293,7 +294,7 @@ func (s *VarsLoaderTestSuite) TestGit() {
 }
 
 func (s *VarsLoaderTestSuite) TestGitBranch() {
-	gs := git.NewTestGitServer(s.T())
+	gs := test_utils.NewTestGitServer(s.T())
 	gs.GitInit("repo")
 
 	wt := gs.GetWorktree("repo")
@@ -315,7 +316,7 @@ func (s *VarsLoaderTestSuite) TestGitBranch() {
 	})
 	assert.NoError(s.T(), err)
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		url, _ := types.ParseGitUrl(gs.GitRepoUrl("repo"))
 		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Git: &types.VarsSourceGit{
@@ -345,7 +346,7 @@ func (s *VarsLoaderTestSuite) TestClusterConfigMap() {
 	err := s.k.Client.Create(context.TODO(), &cm)
 	assert.NoError(s.T(), err)
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			ClusterConfigMap: &types.VarsSourceClusterConfigMapOrSecret{
 				Name:      "cm",
@@ -359,7 +360,7 @@ func (s *VarsLoaderTestSuite) TestClusterConfigMap() {
 		assert.Equal(s.T(), int64(42), v)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			ClusterConfigMap: &types.VarsSourceClusterConfigMapOrSecret{
 				Name:      "cm1",
@@ -379,7 +380,7 @@ func (s *VarsLoaderTestSuite) TestClusterConfigMap() {
 		assert.EqualError(s.T(), err, fmt.Sprintf("key vars1 not found in %s/ConfigMap/cm on cluster", s.namespace()))
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		b := true
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			IgnoreMissing: &b,
@@ -392,7 +393,7 @@ func (s *VarsLoaderTestSuite) TestClusterConfigMap() {
 		assert.NoError(s.T(), err)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			ClusterConfigMap: &types.VarsSourceClusterConfigMapOrSecret{
 				Name:      "cm",
@@ -403,7 +404,7 @@ func (s *VarsLoaderTestSuite) TestClusterConfigMap() {
 		assert.Errorf(s.T(), err, "failed to load vars from kubernetes object default/ConfigMap/cm and key value: value is not a YAML dictionary")
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			ClusterConfigMap: &types.VarsSourceClusterConfigMapOrSecret{
 				Name:       "cm",
@@ -432,7 +433,7 @@ func (s *VarsLoaderTestSuite) TestClusterSecret() {
 	err := s.k.Client.Create(context.TODO(), &secret)
 	assert.NoError(s.T(), err)
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			ClusterSecret: &types.VarsSourceClusterConfigMapOrSecret{
 				Name:      "s",
@@ -446,7 +447,7 @@ func (s *VarsLoaderTestSuite) TestClusterSecret() {
 		assert.Equal(s.T(), int64(42), v)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			ClusterSecret: &types.VarsSourceClusterConfigMapOrSecret{
 				Name:      "s1",
@@ -466,7 +467,7 @@ func (s *VarsLoaderTestSuite) TestClusterSecret() {
 		assert.EqualError(s.T(), err, fmt.Sprintf("key vars1 not found in %s/Secret/s on cluster", s.namespace()))
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		b := true
 		vs := &types.VarsSource{
 			IgnoreMissing: &b,
@@ -503,7 +504,7 @@ func (s *VarsLoaderTestSuite) TestK8sObjectLabels() {
 	err = s.k.Client.Create(context.TODO(), &cm2)
 	assert.NoError(s.T(), err)
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			ClusterConfigMap: &types.VarsSourceClusterConfigMapOrSecret{
 				Labels:    map[string]string{"label1": "value1"},
@@ -517,7 +518,7 @@ func (s *VarsLoaderTestSuite) TestK8sObjectLabels() {
 		assert.Equal(s.T(), int64(42), v)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			ClusterConfigMap: &types.VarsSourceClusterConfigMapOrSecret{
 				Labels:    map[string]string{"label2": "value2"},
@@ -531,7 +532,7 @@ func (s *VarsLoaderTestSuite) TestK8sObjectLabels() {
 		assert.Equal(s.T(), int64(43), v)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		b := true
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			IgnoreMissing: &b,
@@ -550,7 +551,7 @@ func (s *VarsLoaderTestSuite) TestSystemEnv() {
 	s.T().Setenv("TEST2", "'43'")
 	s.T().Setenv("TEST4", "44")
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			SystemEnvVars: uo.FromMap(map[string]interface{}{
 				"test1": "TEST1",
@@ -588,7 +589,7 @@ func (s *VarsLoaderTestSuite) TestSystemEnv() {
 		assert.Equal(s.T(), "", v)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			SystemEnvVars: uo.FromMap(map[string]interface{}{
 				"test5": "TEST5",
@@ -597,7 +598,7 @@ func (s *VarsLoaderTestSuite) TestSystemEnv() {
 		assert.EqualError(s.T(), err, "environment variable TEST5 not found for test5")
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		b := true
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			IgnoreMissing: &b,
@@ -624,7 +625,7 @@ func (s *VarsLoaderTestSuite) TestHttp_GET() {
 	}))
 	defer ts.Close()
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		u, _ := url.Parse(ts.URL)
 		u.Path += "/ok"
 
@@ -639,7 +640,7 @@ func (s *VarsLoaderTestSuite) TestHttp_GET() {
 		assert.Equal(s.T(), int64(42), v)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		b := true
 		u, _ := url.Parse(ts.URL)
 		u.Path += "/missing"
@@ -652,7 +653,7 @@ func (s *VarsLoaderTestSuite) TestHttp_GET() {
 		assert.NoError(s.T(), err)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		b := true
 		u, _ := url.Parse(ts.URL)
 		u.Path += "/error"
@@ -688,7 +689,7 @@ func (s *VarsLoaderTestSuite) TestHttp_POST() {
 
 	u, _ := url.Parse(ts.URL)
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Http: &types.VarsSourceHttp{
 				Url: types.YamlUrl{URL: *u},
@@ -735,7 +736,7 @@ func (s *VarsLoaderTestSuite) TestHttp_JsonPath() {
 
 	u, _ := url.Parse(ts.URL)
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Http: &types.VarsSourceHttp{
 				Url:      types.YamlUrl{URL: *u},
@@ -750,7 +751,7 @@ func (s *VarsLoaderTestSuite) TestHttp_JsonPath() {
 }
 
 func (s *VarsLoaderTestSuite) TestAwsSecretsManager() {
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		aws.Secrets = map[string]string{
 			"secret": `{"test1": {"test2": 42}}`,
 		}
@@ -774,7 +775,7 @@ func (s *VarsLoaderTestSuite) TestAwsSecretsManager() {
 		assert.Equal(s.T(), int64(42), v)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		aws.Secrets = map[string]string{
 			"secret": `{"test1": {"test2": 42}}`,
 		}
@@ -790,7 +791,7 @@ func (s *VarsLoaderTestSuite) TestAwsSecretsManager() {
 		assert.Equal(s.T(), int64(42), v)
 	})
 
-	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory) {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		aws.Secrets = map[string]string{
 			"secret": `{"test1": {"test2": 42}}`,
 		}
@@ -806,3 +807,50 @@ func (s *VarsLoaderTestSuite) TestAwsSecretsManager() {
 		assert.NoError(s.T(), err)
 	})
 }
+
+func (s *VarsLoaderTestSuite) TestGcpSecretManager() {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		gcp.Secrets = map[string]string{
+			"projects/my-project/secrets/secret/versions/latest": `{"test1": {"test2": 42}}`,
+		}
+
+		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			GcpSecretManager: &types.VarsSourceGcpSecretManager{
+				SecretName: "projects/my-project/secrets/secret/versions/latest",
+			},
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		v, _, _ := vc.Vars.GetNestedInt("test1", "test2")
+		assert.Equal(s.T(), int64(42), v)
+	})
+
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		gcp.Secrets = map[string]string{
+			"projects/my-project/secrets/secret/versions/latest": `{"test1": {"test2": 42}}`,
+		}
+
+		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			GcpSecretManager: &types.VarsSourceGcpSecretManager{
+				SecretName: "projects/different-project/secrets/secret/versions/latest",
+			},
+		}, nil, "")
+		assert.EqualError(s.T(), err, "secret not found: failed to access secret version: rpc error: code = NotFound desc = secret not found: failed to access secret version: rpc error: code = NotFound desc = secret projects/different-project/secrets/secret/versions/latest not found")
+
+	})
+
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		gcp.Secrets = map[string]string{
+			"projects/my-project/secrets/secret/versions/latest": `{"test1": {"test2": 42}}`,
+		}
+
+		b := true
+		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			IgnoreMissing: &b,
+			GcpSecretManager: &types.VarsSourceGcpSecretManager{
+				SecretName: "projects/my-project/secrets/missing-secret/versions/latest",
+			},
+		}, nil, "")
+		assert.NoError(s.T(), err)
+	})
+}
